kapps_triplestore_interface.exceptions#

exception kapps_triplestore_interface.exceptions.TripleStoreInterfaceError[source]#

Bases: Exception

Base exception for the GraphDB interface.

Serves as the common ancestor for all custom exceptions in this package to allow catching them collectively when desired.

exception kapps_triplestore_interface.exceptions.InvalidRepositoryError(message: str)[source]#

Bases: TripleStoreInterfaceError

Invalid repository configuration or selection.

Parameters:

message (str) – Explanation of why the repository is invalid.

exception kapps_triplestore_interface.exceptions.AuthenticationError(message: str)[source]#

Bases: TripleStoreInterfaceError

Authentication failure when communicating with GraphDB.

Parameters:

message (str) – Details about the authentication error.

exception kapps_triplestore_interface.exceptions.InvalidQueryError(message: str)[source]#

Bases: TripleStoreInterfaceError

Invalid SPARQL query or update string.

Parameters:

message (str) – Description of why the query is invalid.

exception kapps_triplestore_interface.exceptions.InvalidInputError(message: str)[source]#

Bases: TripleStoreInterfaceError

Invalid input provided to an interface method.

Parameters:

message (str) – Explanation of the invalid input condition.

exception kapps_triplestore_interface.exceptions.InvalidIRIError(message: str)[source]#

Bases: TripleStoreInterfaceError

Invalid IRI value or format encountered.

Parameters:

message (str) – Description of the IRI validation failure.

exception kapps_triplestore_interface.exceptions.GraphDbException(message: str)[source]#

Bases: TripleStoreInterfaceError

General error raised for HTTP or runtime issues with GraphDB.

Parameters:

message (str) – The error message returned or constructed for the failure.